#
# spec file for package qview
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qview
Version:        6.1
Release:        1.4
Summary:        Practical and minimal image viewer
License:        GPL-3.0-only
Group:          Productivity/Graphics/Viewers
URL:            https://interversehq.com/qview/
Source:         https://github.com/jurplel/qView/releases/download/%{version}/qView-%{version}.tar.gz#/qView-%{version}.tar.gz
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.14
BuildRequires:  pkgconfig(Qt5Network) >= 5.14
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.14
Recommends:     libqt5-qtimageformats

%description
qView is a Qt image viewer designed with minimalism and usability in mind.
No cluttered interface, just your image and a titlebar.

%prep
%setup -q -n qView

%build
%qmake5 PREFIX=%{_prefix}
%make_build

%install
INSTALL_ROOT=%{buildroot} %make_install

%files
%license LICENSE
%doc README.md
%{_bindir}/*
%{_datadir}/icons/*
%{_datadir}/applications/*
%{_datadir}/metainfo/

%changelog
* Thu Aug 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 6.1:
  * Fix segfaults on Linux under Wayland.
  * Fix jxl files not being shown in the file picker properly.
  * Fix issue where png files did not use embedded color profiles.
  * Fix incorrect cache cost value.
* Fri Aug 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 6.0:
  New features:
  * Support color profiles (Requires Qt >=5.14 if you're building yourself).
  * Support dragging and dropping a folder.
  * Add sorting by creation date
  Bugfixes:
  * Fix image switching being much slower than expected on folders with a lot of files.
  * Fix slowness when opening files from a network share.
  * Fix GIFs not moving from the center of the viewport.
  * Fix crash when switching images on Linux.
  * Fix application menu becoming empty on macOS when all windows are closed.
  Distribution changes:
  * kimageformats is now included in an even more automated fashion.
  * HEIF and AVIF are now from kimageformats.
  * raw image format support now included.
* Sun Jan 16 2022 Andrey Karepin <egdfree@opensuse.org>
- add libqt5-qtimageformats to recommends
* Sun Jan 16 2022 Andrey Karepin <egdfree@opensuse.org>
- update to 5.0
  * "Open With" functionality to open images in other applications
  * Image deletion
  * Significantly better trackpad experience
  * Localization support, with many community-supplied translations
  * More image formats supported (.jxl, .psd, many others as kimageformats is now bundled)
  * Zooming from original size
  * Image now reverts to original resolution when zooming past the scaling threshold (images aren't blurry when zooming in close)
  * Option to exit the app when the last window is closed on macOS
  * Resize dialog now highlights text without file extension
  * Middle click now resets scale, why not
  * Added an option for a basic bar to show the titlebar text in fullscreen mode.
  * Qt 6 support
  * Reaching an invalid image now allows you to keep moving through the current folder with the arrow keys
  * Fix Open URL not working in some cases where the app is in a non-user writable location
  * Fix crashing on Wayland (window won't center when resizing, though)
  * Fix smoothness issue when resizing window
  * Fix not being able to rename on Windows
  * Fix Mac crash when opening preferences
  * Fix disabling recent files not working properly
* Sat Oct 31 2020 Andrey Karepin <egdfree@opensuse.org>
- update to 4.0
  * Integrate native cocoa components on macOS for a more native-like experience, as well as just working on the macOS experience in general
  * Add rename function
  * Include support for .heif, .avif, and .apng images
  * Extra titlebar mode that shows only the image name and the position in the folder
  * Opt-in update notification system that works right after the program starts
  * Add randomized sort option
  * You can now close a window with Ctrl/⌘+W
  * Text in the file info dialog is now selectable
  * Added configurable minimum size for "window matches image size" option
  * Improved error messages
  * Add icons to recents menu
  * Fix weird titlebar vibrancy on macOS
  * Fix image not filling window properly with titlebar enabled
  * Fixed window position issue with vertical monitor setups
  * Fixed fullscreen causing window size to reset
  * Fixed various bugs with recents, shortcuts, and options due to a massive refactoring project to hopefully make maintenance easier in the future
  * Fix awful hi-dpi sizing
  * Fix bug with opening images from Finder replacing currently open images on macOS
  * Distribute Appimages for Linux through a new CI pipeline
  * Distribute build for legacy OS X 10.10+
  * Include symbolic icon on linux (for GNOME, primarily)
  * Include appdata manifest on linux
* Wed Mar  4 2020 Andrey Karepin <egdfree@opensuse.org>
- fix download source link (bnc#1165355)
* Mon Jan 13 2020 Andrey Karepin <egdfree@opensuse.org>
- update to 3.0
  * Added keyboard shortcut customization
  * Added the ability to open images from URLs
  * Added the ability to open multiple images from the file dialog
  * Added the ability to copy images from the application
  * Added option to change file sorting
  * Added high DPI support
  * SVGs are now displayed in a high resolution
  * Slideshow timer is now configurable in tenths of a second
  * Added option to not display the recents list
  * Added option to disable scrolling "towards the cursor"
  * The recents menu is now more proactive in clearing out entries that no longer exist
  * Fixed small bug with the "window matches image size" option
  * Fixed bug where the window would exceed the screen boundaries with the "window matches image size" option enabled
  * Fixed crashing with multiple windows under macOS
  * Fixed dock menu oddities under macOS
* Mon Jun  3 2019 Andrey Karepin <egdfree@opensuse.org>
- fix download source url
* Wed May 29 2019 Andrey Karepin <egdfree@opensuse.org>
- initial package for openSUSE
